pub enum FallbackStrategy {
PreferredNumber,
PreferredDate,
PreferredTime,
SurfaceDate,
SurfaceTime,
Literal,
UnicodeCodePoint,
}Expand description
Applied source-faithful rendering strategy.
Variants
PreferredNumber
A validated number or neutral sentence-final numeric period.
PreferredDate
A validated date, adopting its written date format without an explicit cue.
PreferredTime
A validated clock, adopting its written clock format without an explicit cue.
SurfaceDate
Date-shaped source components without calendar certification.
SurfaceTime
Clock-shaped source components without clock certification.
Literal
Ordered literal words, letters, digits and symbol names.
UnicodeCodePoint
One or more unnamed scalars spoken as conventional hexadecimal U+ codes.