pub enum HintKind {
Cardinal,
Digits,
Date,
Time,
Ordinal,
Roman,
Range,
Telephone,
Electronic,
}Expand description
Explicit interpretation of a whole original-source span.
Variants
Cardinal
An exact integer, including valid grouping and explicit zero-padding intent.
Digits
ASCII digits, optional initial plus, and space/dot/slash/hyphen/parentheses.
Date
A valid numeric Gregorian date.
Time
A valid 24-hour clock.
Ordinal
Explicit ordinal intent on a numeric period or ordinal suffix expression.
Roman
Canonical uppercase Roman numeral; period establishes ordinal intent.
Range
Exact bounded numeric endpoints with optional quantity context.
Telephone
Turkish national or +90 telephone reading.
Electronic
Supported whole ASCII address or cued/hinted bare domain.